/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ServiceCustomIssueTrackerConfig extends cdktf.TerraformMetaArguments {
    /**
    * The URL to view an issue in the external issue tracker. Must contain :id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.3.0/docs/resources/service_custom_issue_tracker#issues_url ServiceCustomIssueTracker#issues_url}
    */
    readonly issuesUrl: string;
    /**
    * The ID or full path of the project for the custom issue tracker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.3.0/docs/resources/service_custom_issue_tracker#project ServiceCustomIssueTracker#project}
    */
    readonly project: string;
    /**
    * The URL to the project in the external issue tracker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.3.0/docs/resources/service_custom_issue_tracker#project_url ServiceCustomIssueTracker#project_url}
    */
    readonly projectUrl: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.3.0/docs/resources/service_custom_issue_tracker gitlab_service_custom_issue_tracker}
*/
export declare class ServiceCustomIssueTracker extends cdktf.TerraformResource {
    static readonly tfResourceType = "gitlab_service_custom_issue_tracker";
    /**
    * Generates CDKTF code for importing a ServiceCustomIssueTracker resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ServiceCustomIssueTracker to import
    * @param importFromId The id of the existing ServiceCustomIssueTracker that should be imported. Refer to the {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.3.0/docs/resources/service_custom_issue_tracker#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ServiceCustomIssueTracker to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.3.0/docs/resources/service_custom_issue_tracker gitlab_service_custom_issue_tracker} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ServiceCustomIssueTrackerConfig
    */
    constructor(scope: Construct, id: string, config: ServiceCustomIssueTrackerConfig);
    get active(): cdktf.IResolvable;
    get createdAt(): string;
    get id(): string;
    private _issuesUrl?;
    get issuesUrl(): string;
    set issuesUrl(value: string);
    get issuesUrlInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    get projectInput(): string | undefined;
    private _projectUrl?;
    get projectUrl(): string;
    set projectUrl(value: string);
    get projectUrlInput(): string | undefined;
    get slug(): string;
    get updatedAt(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
